# ignite-rich-logger
![Build status](https://github.com/jonghwanhyeon/ignite-rich-logger/actions/workflows/publish.yml/badge.svg)

A logger that displays a progress bar and metrics using the Rich library

[![Demonstration](https://asciinema.org/a/681227.svg)](https://asciinema.org/a/681227)

## Install
To install **ignite-rich-logger**, simply use pip:

```console
$ pip install ignite-rich-logger
```